@@ -74,9 +74,12 @@ pref("extensions.enigmail.initAlert",true);
 // use -a for encrypting attachments for inline PGP
 pref("extensions.enigmail.inlineAttachAsciiArmor",false);
 
-// extension to append for encrypting attachments for inline PGP
+// extension to append for inline-encrypted attachments
 pref("extensions.enigmail.inlineAttachExt",".pgp");
 
+// extension to append for inline-signed attachments
+pref("extensions.enigmail.inlineSigAttachExt",".sig");
+
 // debug log directory (if set, also enabled debugging)
 pref("extensions.enigmail.logDirectory","");
 
@@ -123,7 +126,7 @@ pref("extensions.enigmail.supportMultiPass",false);
 pref("extensions.enigmail.useDefaultComment",false);
 
 // max message size to verify RFC 3156 section 6.1 messages
-pref("extensions.enigmail.encapsulatedMimeMaxSize", 20000);
+pref("extensions.enigmail.encapsulatedMimeMaxSize", 8000);
 
 // use gpg passphrase agent for passphrase handling
 pref("extensions.enigmail.useGpgAgent",false);
